@@ -20,12 +20,11 @@ package org.ddogleg.clustering.gmm;
 
 import org.ddogleg.clustering.AssignCluster;
 import org.ddogleg.clustering.ComputeClusters;
-import org.ddogleg.struct.FastQueue;
-import org.ddogleg.struct.GrowQueue_F64;
+import org.ddogleg.struct.DogArray;
+import org.ddogleg.struct.DogArray_F64;
+import org.ddogleg.struct.LArrayAccessor;
 import org.ejml.dense.row.CommonOps_DDRM;
 
-import java.util.List;
-
 /**
  * Standard expectation maximization based approach to fitting mixture-of-Gaussian models to a set of data.
  * A locally optimal maximum likelihood estimate is found.  The full covariance is found.  Some other
@@ -41,20 +40,25 @@ import java.util.List;
 // TODO Unconstrained covariance
 // TODO just diagonal covariance
 	// TODO added shared and tied covariance?
+@SuppressWarnings("NullAway.Init")
 public class ExpectationMaximizationGmm_F64 implements ComputeClusters<double[]>  {
 
 	 // Used to select initial parameters
 	InitializeGmm_F64 selectInitial;
 
 	// storage for mixture models
-	FastQueue<GaussianGmm_F64> mixture;
+	DogArray<GaussianGmm_F64> mixture;
 
 	// info for each points
-	FastQueue<PointInfo> info = new FastQueue<>(PointInfo::new);
+	@SuppressWarnings("NullAway")
+	DogArray<PointInfo> info;
 
-	// Maximum number of iterations\
+	// Maximum number of iterations
 	int maxIterations;
 
+	// Number of elements in a point
+	int pointDimension;
+
 	// If the fractional change in score is less or equal to this value then it has converged.
 	// ||prev-curr||/prev
 	double convergeTol;
@@ -63,7 +67,7 @@ public class ExpectationMaximizationGmm_F64 implements ComputeClusters<double[]>
 	GaussianLikelihoodManager likelihoodManager;
 
 	// internal work space for computing the difference between the mean and point
-	double dx[] = new double[1];
+	double[] dx = new double[1];
 
 	// compute chi-square error
 	double errorChiSquare;
@@ -80,18 +84,22 @@ public class ExpectationMaximizationGmm_F64 implements ComputeClusters<double[]>
 	 */
 	public ExpectationMaximizationGmm_F64(int maxIterations,
 										  double convergeTol,
+										  int pointDimension,
 										  InitializeGmm_F64 selectInitial) {
 		this.maxIterations = maxIterations;
 		this.convergeTol = convergeTol;
 		this.selectInitial = selectInitial;
+		this.pointDimension = pointDimension;
+
+		info = new DogArray<>(()->new PointInfo(pointDimension));
+		mixture = new DogArray<>(()->new GaussianGmm_F64(pointDimension));
 
 		System.err.println("WARNING:  GMM-EM is a work in progress!  Might not work in your situation");
 	}
 
 	@Override
-	public void init(final int pointDimension, long randomSeed) {
-		mixture = new FastQueue<>(()->new GaussianGmm_F64(pointDimension));
-		selectInitial.init(pointDimension,randomSeed);
+	public void initialize(long randomSeed) {
+		selectInitial.init(pointDimension, randomSeed);
 
 		if( dx.length < pointDimension )
 			dx = new double[pointDimension];
@@ -99,16 +107,19 @@ public class ExpectationMaximizationGmm_F64 implements ComputeClusters<double[]>
 	}
 
 	@Override
-	public void process(List<double[]> points, int numCluster) {
+	public void process( LArrayAccessor<double[]> points, int numCluster) {
 		// setup data structures
 		mixture.resize(numCluster);
+		info.resize(points.size());
+
 		for (int i = 0; i < points.size(); i++) {
-			PointInfo p = info.grow();
-			p.point = points.get(i);
+			PointInfo p = info.get(i);
+			points.getCopy(i,p.point);
 			p.weights.resize(numCluster);
 		}
 
 		if( verbose ) System.out.println("GMM-EM: Selecting initial seeds");
+
 		// Select initial distributions
 		selectInitial.selectSeeds(points,mixture.toList());
 		likelihoodManager.precomputeAll();
@@ -134,11 +145,6 @@ public class ExpectationMaximizationGmm_F64 implements ComputeClusters<double[]>
 			maximization();
 			likelihoodManager.precomputeAll();
 		}
-
-		// clean up
-		for (int i = 0; i < info.size; i++) {
-			info.data[i].point = null; // de-reference so the memory could be freed
-		}
 		info.reset();
 	}
 
@@ -254,9 +260,17 @@ public class ExpectationMaximizationGmm_F64 implements ComputeClusters<double[]>
 		this.verbose = verbose;
 	}
 
+	@Override public ComputeClusters<double[]> newInstanceThread() {
+		throw new RuntimeException("Not yet implemented");
+	}
+
 	public static class PointInfo
 	{
-		public double[] point; // reference to the original input point
-		public GrowQueue_F64 weights = new GrowQueue_F64();
+		public double[] point;
+		public DogArray_F64 weights = new DogArray_F64();
+
+		public PointInfo(int pointDimension) {
+			point = new double[pointDimension];
+		}
 	}
 }
