@@ -50,6 +50,7 @@ import java.util.Random;
  *
  * @author Peter Abeles
  */
+@SuppressWarnings("NullAway.Init")
 public class RansacMulti<Point> implements ModelMatcherMulti<Point> {
 	// how many points are drawn to generate the model
 	protected int sampleSize;
@@ -226,7 +227,7 @@ public class RansacMulti<Point> implements ModelMatcherMulti<Point> {
 		for (int i = 0; i < dataSet.size(); i++) {
 			Point point = dataSet.get(i);
 
-			double distance = modelDistance.computeDistance(point);
+			double distance = modelDistance.distance(point);
 			if (distance < threshold) {
 				matchToInput[candidatePoints.size()] = i;
 				candidatePoints.add(point);
@@ -249,6 +250,7 @@ public class RansacMulti<Point> implements ModelMatcherMulti<Point> {
 		bestFitParam = param;
 	}
 
+	@Override
 	public List<Point> getMatchSet() {
 		return bestFitPoints;
 	}
@@ -330,6 +332,7 @@ public class RansacMulti<Point> implements ModelMatcherMulti<Point> {
 	/**
 	 * Describes a model and RANSAC fit parameters for specific type of object.
 	 */
+	@SuppressWarnings("NullAway.Init")
 	public static class ObjectType<Model,Point>
 	{
 		/** how close a point needs to be considered part of the model */
