@@ -18,13 +18,14 @@
 
 package org.ddogleg.graph;
 
-import org.ddogleg.struct.FastQueue;
+import org.ddogleg.struct.DogArray;
+import org.jetbrains.annotations.Nullable;
 
 /**
  * @author Peter Abeles
  */
 public class Node<N,E>
 {
-   N data;
-   FastQueue<Edge<N,E>> edges = new FastQueue<>(Edge<N,E>::new);
+   @Nullable N data;
+   final DogArray<Edge<N,E>> edges = new DogArray<>(Edge::new);
 }
