@@ -20,9 +20,10 @@ package org.ddogleg.nn.alg;
 
 import org.ddogleg.nn.NearestNeighbor;
 import org.ddogleg.nn.NnData;
+import org.ddogleg.struct.DogArray;
+import org.ddogleg.struct.DogArray_I32;
 import org.ddogleg.struct.FastArray;
-import org.ddogleg.struct.FastQueue;
-import org.ddogleg.struct.GrowQueue_I32;
+import org.jetbrains.annotations.Nullable;
 
 import java.util.List;
 import java.util.PriorityQueue;
@@ -50,11 +51,12 @@ import java.util.Random;
  *
  * @author Karel Petránek
  */
+@SuppressWarnings("NullAway.Init")
 public class VpTree implements NearestNeighbor<double[]> {
-	GrowQueue_I32 indexes;
+	DogArray_I32 indexes;
 	private double[][] items;
-	private Node root;
-	private Random random;
+	private @Nullable Node root;
+	private final Random random;
 
 	/**
 	 * Constructor
@@ -70,7 +72,7 @@ public class VpTree implements NearestNeighbor<double[]> {
 	public void setPoints(List<double[]> points, boolean trackIndicies) {
 		// Make a copy because we mutate the lists
 		this.items = points.toArray(new double[0][]);
-		this.indexes = new GrowQueue_I32();
+		this.indexes = new DogArray_I32();
 		indexes.resize(points.size());
 		for (int i = 0; i < points.size(); i++) {
 			indexes.data[i] = i;
@@ -86,7 +88,7 @@ public class VpTree implements NearestNeighbor<double[]> {
 	 * @param upper end of range (exclusive)
 	 * @return root of the tree or null if lower == upper
 	 */
-	private Node buildFromPoints(int lower, int upper) {
+	private @Nullable Node buildFromPoints(int lower, int upper) {
 		if (upper == lower) {
 			return null;
 		}
@@ -172,13 +174,12 @@ public class VpTree implements NearestNeighbor<double[]> {
 		list[b] = tmp;
 	}
 
-	private void listSwap(GrowQueue_I32 list, int a, int b) {
+	private void listSwap( DogArray_I32 list, int a, int b) {
 		int tmp = list.get(a);
 		list.data[a] = list.data[b];
 		list.data[b] = tmp;
 	}
 
-
 	@Override
 	public Search<double[]> createSearch() {
 		return new InternalSearch();
@@ -195,7 +196,7 @@ public class VpTree implements NearestNeighbor<double[]> {
 
 		@Override
 		public void findNearest(double[] target, double maxDistance,
-								int numNeighbors, FastQueue<NnData<double[]>> results)
+								int numNeighbors, DogArray<NnData<double[]>> results)
 		{
 			results.reset();
 			PriorityQueue<HeapItem> heap = search(target, maxDistance < 0 ? Double.POSITIVE_INFINITY : Math.sqrt(maxDistance), numNeighbors);
@@ -319,15 +320,14 @@ public class VpTree implements NearestNeighbor<double[]> {
 		}
 	}
 
-
 	/**
 	 * Separates the points to "closer than the threshold" (left) and "farther than the threshold" (right).
 	 */
 	private static class Node {
 		int index;
 		double threshold;
-		Node left;
-		Node right;
+		@Nullable Node left;
+		@Nullable Node right;
 	}
 
 	/**
