@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2015, Peter Abeles. All Rights Reserved.
+ * Copyright (c) 2012-2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of DDogleg (http://ddogleg.org).
  *
@@ -18,37 +18,36 @@
 
 package org.ddogleg.struct;
 
+import lombok.Getter;
+import lombok.Setter;
+import org.jetbrains.annotations.Nullable;
+
+import java.util.Objects;
+
 /**
  * Simple data structure for passing a pair of data.
  *
  * @author Peter Abeles
  */
 public class Tuple2<A,B> {
-	public A data0;
-	public B data1;
+	public @Nullable @Getter @Setter A d0;
+	public @Nullable @Getter @Setter B d1;
 
-	public Tuple2(A data0, B data1) {
-		this.data0 = data0;
-		this.data1 = data1;
+	public Tuple2(@Nullable A d0, @Nullable B d1) {
+		this.d0 = d0;
+		this.d1 = d1;
 	}
 
-	public Tuple2() {
+	public Tuple2() {}
+
+	/** Returns d0 but performs a null check first */
+	public A getCheckD0() {
+		return Objects.requireNonNull(d0);
 	}
 
-	public A getData0() {
-		return data0;
-	}
-
-	public void setData0(A data0) {
-		this.data0 = data0;
-	}
-
-	public B getData1() {
-		return data1;
-	}
-
-	public void setData1(B data1) {
-		this.data1 = data1;
+	/** Returns d1 but performs a null check first */
+	public B getCheckD1() {
+		return Objects.requireNonNull(d1);
 	}
 }
 
