@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2018, Peter Abeles. All Rights Reserved.
+ * Copyright (c) 2012-2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of DDogleg (http://ddogleg.org).
  *
@@ -18,47 +18,43 @@
 
 package org.ddogleg.struct;
 
+import lombok.Getter;
+import lombok.Setter;
+import org.jetbrains.annotations.Nullable;
+
+import java.util.Objects;
+
 /**
  * Simple data structure for passing a triple of data.
  *
  * @author Peter Abeles
  */
 public class Tuple3<A,B,C> {
-	public A d0;
-	public B d1;
-	public C d2;
+	public @Nullable @Getter @Setter A d0;
+	public @Nullable @Getter @Setter B d1;
+	public @Nullable @Getter @Setter C d2;
 
-	public Tuple3(A d0, B d1, C d2) {
+	public Tuple3(@Nullable A d0, @Nullable B d1, @Nullable C d2) {
 		this.d0 = d0;
 		this.d1 = d1;
 		this.d2 = d2;
 	}
 
-	public Tuple3() {
+	public Tuple3() {}
+
+	/** Returns d0 but performs a null check first */
+	public A getCheckD0() {
+		return Objects.requireNonNull(d0);
 	}
 
-	public A getD0() {
-		return d0;
+	/** Returns d1 but performs a null check first */
+	public B getCheckD1() {
+		return Objects.requireNonNull(d1);
 	}
 
-	public void setD0(A d0) {
-		this.d0 = d0;
-	}
-
-	public B getD1() {
-		return d1;
-	}
-
-	public void setD1(B d1) {
-		this.d1 = d1;
-	}
-
-	public void setD2(C d2) {
-		this.d2 = d2;
-	}
-
-	public C getD2() {
-		return d2;
+	/** Returns d2 but performs a null check first */
+	public C getCheckD2() {
+		return Objects.requireNonNull(d2);
 	}
 }
 
