@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2015, Peter Abeles. All Rights Reserved.
+ * Copyright (c) 2012-2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of DDogleg (http://ddogleg.org).
  *
@@ -23,7 +23,7 @@ package org.ddogleg.clustering.kmeans;
  */
 public class TestInitializeStandard_F64 extends StandardInitializeKMeansChecks {
 	@Override
-	public InitializeKMeans_F64 createAlg() {
-		return new InitializeStandard_F64();
+	public InitializeKMeans<double[]> createAlg(int dof) {
+		return new InitializeStandard<>();
 	}
 }
