@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2018, Peter Abeles. All Rights Reserved.
+ * Copyright (c) 2012-2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of DDogleg (http://ddogleg.org).
  *
@@ -18,24 +18,23 @@
 
 package org.ddogleg.fitting.modelset;
 
-import java.util.List;
+import org.jetbrains.annotations.Nullable;
 
+import java.util.List;
 
 /**
  * Computes the mean of a set of points.
  *
  * @author Peter Abeles
  */
-public class MeanModelFitter implements ModelFitter<double[],Double> ,
-		ModelGenerator<double[],Double>{
-
+public class MeanModelFitter implements ModelFitter<double[], Double>, ModelGenerator<double[], Double> {
 	@Override
-	public boolean generate(List<Double> dataSet, double[] param ) {
-		return fitModel(dataSet,null,param);
+	public boolean generate( List<Double> dataSet, double[] param ) {
+		return fitModel(dataSet, null, param);
 	}
 
 	@Override
-	public boolean fitModel(List<Double> dataSet, double[] initParam, double[] foundParam) {
+	public boolean fitModel( List<Double> dataSet, @Nullable double[] initParam, double[] foundParam ) {
 		double mean = 0;
 
 		for (double d : dataSet) {
