@@ -36,9 +36,9 @@ public class TestStatisticalDistanceModelMatcher extends GenericModelMatcherTest
 															ModelGenerator<double[],Double> generator,
 															ModelFitter<double[],Double> fitter,
 															int minPoints, double fitThreshold) {
-		return new StatisticalDistanceModelMatcher<double[],Double>(5, 0, 0, 10000, minPoints,
+		return new StatisticalDistanceModelMatcher<>(5, 0, 0, 10000, minPoints,
 				StatisticalDistance.PERCENTILE,
-				0.95, manager,fitter, distance, new ArrayCodec());
+				0.95, manager, generator, distance, new ArrayCodec());
 	}
 
 	private static class ArrayCodec implements ModelCodec<double[]>
