@@ -18,24 +18,24 @@
 
 package org.ddogleg.fitting.modelset.lmeds;
 
-import org.ddogleg.fitting.modelset.*;
+import org.ddogleg.fitting.modelset.GenericModelMatcherPostTests;
+import org.ddogleg.fitting.modelset.ModelManager;
+import org.ddogleg.fitting.modelset.ModelMatcherPost;
 
 
 /**
  * @author Peter Abeles
  */
-public class TestLeastMedianOfSquares extends GenericModelMatcherTests {
+public class TestLeastMedianOfSquares extends GenericModelMatcherPostTests {
 
 	public TestLeastMedianOfSquares() {
 		configure(0.9, 0.1, false);
 	}
 
 	@Override
-	public ModelMatcher<double[],Double> createModelMatcher(ModelManager<double[]> manager,
-															DistanceFromModel<double[],Double> distance,
-															ModelGenerator<double[],Double> generator,
-															ModelFitter<double[],Double> fitter,
-															int minPoints, double fitThreshold) {
-		return new LeastMedianOfSquares<>(4234,50,fitThreshold,0.9,manager,generator,distance);
+	public ModelMatcherPost<double[], Double> createModelMatcher( ModelManager<double[]> manager,
+																  int minPoints,
+																  double fitThreshold ) {
+		return new LeastMedianOfSquares<>(4234,50,fitThreshold,0.9,manager, Double.class);
 	}
 }
