@@ -19,33 +19,30 @@
 package org.ddogleg.fitting.modelset.ransac;
 
 import org.ddogleg.fitting.modelset.*;
+import org.ddogleg.struct.DogArray_I32;
 import org.junit.jupiter.api.Test;
 
 import java.util.ArrayList;
 import java.util.List;
+import java.util.Objects;
 
 import static org.junit.jupiter.api.Assertions.*;
 
-
 /**
  * @author Peter Abeles
  */
-public class TestRansac extends GenericModelMatcherTests {
+public class TestRansac extends GenericModelMatcherPostTests {
 
 	public TestRansac() {
 		configure(0.9, 0.05, true);
 	}
 
 	@Override
-	public ModelMatcher<double[],Double> createModelMatcher(ModelManager<double[]> manager,
-															DistanceFromModel<double[],Double> distance,
-															ModelGenerator<double[],Double> generator,
-															ModelFitter<double[],Double> fitter,
-															int minPoints,
-															double fitThreshold) {
-		Ransac<double[],Double> ret = new Ransac<double[],Double>(344, manager,generator, distance, 50, fitThreshold);
+	public ModelMatcherPost<double[], Double> createModelMatcher( ModelManager<double[]> manager,
+																  int minPoints,
+																  double fitThreshold ) {
+		Ransac<double[], Double> ret = new Ransac<>(344, 50, fitThreshold, manager, Double.class);
 		ret.setSampleSize(minPoints);
-
 		return ret;
 	}
 
@@ -56,18 +53,18 @@ public class TestRansac extends GenericModelMatcherTests {
 	@SuppressWarnings({"NumberEquality"})
 	@Test
 	public void randomDraw() {
-		randomDraw_sanity(200,15);
-		randomDraw_sanity(200,150);
+		randomDraw_sanity(200, 15);
+		randomDraw_sanity(200, 150);
 	}
 
-	private void randomDraw_sanity( int total , int numSample ) {
-		List<Integer> dataSet = new ArrayList<Integer>();
+	private void randomDraw_sanity( int total, int numSample ) {
+		List<Integer> dataSet = new ArrayList<>();
 
 		for (int i = 0; i < total; i++) {
 			dataSet.add(i);
 		}
 
-		List<Integer> initSet = new ArrayList<Integer>();
+		List<Integer> initSet = new ArrayList<>();
 		Ransac.randomDraw(dataSet, numSample, initSet, rand);
 
 		assertEquals(numSample, initSet.size());
@@ -80,7 +77,7 @@ public class TestRansac extends GenericModelMatcherTests {
 			assertTrue(dataSet.contains(o));
 
 			// make sure the order has been changed
-			assertTrue(dataSet.get(i) != o);
+			assertNotSame(dataSet.get(i), o);
 
 			// make sure the order has been changed
 			if (o == i)
@@ -88,14 +85,14 @@ public class TestRansac extends GenericModelMatcherTests {
 
 			// make sure only one copy is in the init set
 			for (int j = i + 1; j < initSet.size(); j++) {
-				if (o == initSet.get(j)) {
+				if (o.equals(initSet.get(j))) {
 					fail("Multiple copies in initSet");
 				}
 			}
 		}
 
 		// if the order has been randomized then very few should be in the original order
-		assertTrue(numTheSame < initSet.size() * 0.9);
+		assertTrue(numTheSame < initSet.size()*0.9);
 
 		// call get init set once more and see if it was cleared
 		Ransac.randomDraw(dataSet, numSample, initSet, rand);
@@ -107,30 +104,65 @@ public class TestRansac extends GenericModelMatcherTests {
 	 */
 	@Test
 	public void randomDraw_Histogram() {
-		List<Integer> dataSet = new ArrayList<Integer>();
+		List<Integer> dataSet = new ArrayList<>();
 
 		for (int i = 0; i < 30; i++) {
 			dataSet.add(i);
 		}
-		int histogram[] = new int[ dataSet.size() ];
+		int[] histogram = new int[dataSet.size()];
 
-		List<Integer> selected = new ArrayList<Integer>();
+		List<Integer> selected = new ArrayList<>();
 
 		int numTrials = 10000;
 		for (int i = 0; i < numTrials; i++) {
 			Ransac.randomDraw(dataSet, 3, selected, rand);
 
 			for (int j = 0; j < selected.size(); j++) {
-				histogram[ selected.get(j)]++;
+				histogram[selected.get(j)]++;
 			}
 		}
 
 		double expected = (3.0/30.0)*numTrials;
 
 		for (int i = 0; i < histogram.length; i++) {
-			assertTrue( Math.abs(histogram[i]-expected)/expected < 0.1 );
+			assertTrue(Math.abs(histogram[i] - expected)/expected < 0.1);
+		}
+	}
+
+	/**
+	 * Checks the histogram of selected items to see if it is a uniformly random distribution
+	 */
+	@Test
+	public void randomDraw_integer_Histogram() {
+		DogArray_I32 selectedIdx = new DogArray_I32();
+
+		List<Integer> dataSet = new ArrayList<>();
+		for (int i = 0; i < 30; i++) {
+			dataSet.add(i);
+		}
+		int[] histogram = new int[dataSet.size()];
+
+		List<Integer> selected = new ArrayList<>();
+
+		int numTrials = 10000;
+		for (int i = 0; i < numTrials; i++) {
+			Ransac.randomDraw(selectedIdx, dataSet.size(), 3, rand);
+			Ransac.addSelect(selectedIdx, 3, dataSet, selected);
+
+			for (int idx = 0; idx < selectedIdx.size; idx++) {
+				assertEquals(idx, selectedIdx.get(idx));
+			}
+
+			for (int j = 0; j < selected.size(); j++) {
+				histogram[selected.get(j)]++;
+			}
 		}
 
+		double expected = (3.0/30.0)*numTrials;
+
+		for (int i = 0; i < histogram.length; i++) {
+			assertTrue(Math.abs(histogram[i] - expected)/expected < 0.1);
+		}
 	}
 
 	/**
@@ -140,49 +172,71 @@ public class TestRansac extends GenericModelMatcherTests {
 	public void selectMatchSet() {
 		double modelVal = 50;
 
-		List<Integer> dataSet = new ArrayList<Integer>();
+		List<Integer> dataSet = new ArrayList<>();
+
+		for (int i = 0; i < 200; i++) {
+			dataSet.add(i);
+		}
+		Ransac<double[], Integer> ransac = new Ransac<>(234, 20, 1, new DebugModelStuff((int)modelVal), Integer.class);
+		ransac.setModel(()-> new DebugModelStuff((int)modelVal), ()-> new DebugModelStuff((int)modelVal));
+		ransac.setSampleSize(5);
+		// declare the array so it doesn't blow up when accessed
+		Objects.requireNonNull(ransac.helper).matchToInput = new int[dataSet.size()];
+		double[] param = new double[]{modelVal};
+
+		assertTrue(ransac.helper.selectMatchSet(dataSet, 0, 4, param));
+
+		assertEquals(ransac.helper.candidatePoints.size(), 7);
+	}
+
+	/**
+	 * Checks to see if it will abort if it can't possibly beat the best model
+	 */
+	@Test
+	public void selectMatchSet_abort() {
+		double modelVal = 50;
+
+		List<Integer> dataSet = new ArrayList<>();
 
 		for (int i = 0; i < 200; i++) {
 			dataSet.add(i);
 		}
 
-		DebugModelStuff stuff = new DebugModelStuff((int) modelVal);
-		Ransac<double[],Integer> ransac = new Ransac<double[],Integer>(234,stuff,stuff,stuff,20,1);
+		Ransac<double[], Integer> ransac = new Ransac<>(234, 20, 1, new DebugModelStuff((int)modelVal), Integer.class);
+		ransac.setModel(()-> new DebugModelStuff((int)modelVal), ()-> new DebugModelStuff((int)modelVal));
 		ransac.setSampleSize(5);
 		// declare the array so it doesn't blow up when accessed
-		ransac.matchToInput = new int[ dataSet.size()];
-		double param[] = new double[]{modelVal};
+		Objects.requireNonNull(ransac.helper).matchToInput = new int[dataSet.size()];
+		double[] param = new double[]{modelVal};
 
-		ransac.selectMatchSet(dataSet, 4, param);
-
-		assertTrue(ransac.candidatePoints.size() == 7);
+		assertFalse(ransac.helper.selectMatchSet(dataSet, 150, 4, param));
 	}
 
-	public static class DebugModelStuff implements
-			ModelManager<double[]>,DistanceFromModel<double[],Integer>, ModelGenerator<double[],Integer> {
-
+	@SuppressWarnings({"NullAway"})
+	public static class DebugModelStuff
+			implements ModelManager<double[]>,
+			DistanceFromModel<double[], Integer>,
+			ModelGenerator<double[], Integer> {
 		int threshold;
-
 		double error;
-
 		double[] param;
 
-		public DebugModelStuff(int threshold) {
+		public DebugModelStuff( int threshold ) {
 			this.threshold = threshold;
 		}
 
 		@Override
-		public void setModel(double[] param) {
+		public void setModel( double[] param ) {
 			this.param = param;
 		}
 
 		@Override
-		public double computeDistance(Integer pt) {
+		public double distance( Integer pt ) {
 			return Math.abs(pt - param[0]);
 		}
 
 		@Override
-		public void computeDistance(List<Integer> points, double[] distance) {
+		public void distances( List<Integer> points, double[] distance ) {
 			throw new RuntimeException("Why was this called?");
 		}
 
@@ -202,16 +256,16 @@ public class TestRansac extends GenericModelMatcherTests {
 		}
 
 		@Override
-		public void copyModel(double[] src, double[] dst) {
-			System.arraycopy(src,0,dst,0,1);
+		public void copyModel( double[] src, double[] dst ) {
+			System.arraycopy(src, 0, dst, 0, 1);
 		}
 
 		@Override
-		public boolean generate(List<Integer> dataSet, double[] p) {
+		public boolean generate( List<Integer> dataSet, double[] p ) {
 
 			error = 0;
 
-			int offset = (int) p[0];
+			int offset = (int)p[0];
 
 			for (Integer a : dataSet) {
 				if (a + offset >= threshold) {
