@@ -22,9 +22,9 @@ import org.ddogleg.nn.alg.KdTree;
 import org.ddogleg.nn.alg.KdTreeResult;
 import org.ddogleg.nn.alg.KdTreeSearchN;
 import org.ddogleg.sorting.QuickSelect;
-import org.ddogleg.struct.FastQueue;
-import org.ddogleg.struct.GrowQueue_F64;
-import org.ddogleg.struct.GrowQueue_I32;
+import org.ddogleg.struct.DogArray;
+import org.ddogleg.struct.DogArray_F64;
+import org.ddogleg.struct.DogArray_I32;
 import org.junit.jupiter.api.Test;
 
 import java.util.ArrayList;
@@ -38,10 +38,11 @@ import static org.junit.jupiter.api.Assertions.*;
  *
  * @author Peter Abeles
  */
+@SuppressWarnings({"NullAway"})
 public abstract class StandardKdTreeSearchNTests {
 
 	public int N = 2;
-	FastQueue<KdTreeResult> found = new FastQueue<>(KdTreeResult::new);
+	DogArray<KdTreeResult> found = new DogArray<>(KdTreeResult::new);
 
 	Random rand = new Random(234);
 
@@ -67,22 +68,22 @@ public abstract class StandardKdTreeSearchNTests {
 		found.reset();
 		alg.findNeighbor(new double[]{11, 8}, 1, found);
 		assertEquals(1,found.size);
-		assertTrue(found.data[0].node == tree.root.right.right);
+		assertSame(found.data[0].node, tree.root.right.right);
 
 		// the root will be the best
 		found.reset();
 		alg.findNeighbor(new double[]{1.001, 1.99999}, 1, found);
-		assertTrue(found.data[0].node == tree.root);
+		assertSame(found.data[0].node, tree.root);
 
 		// a point on the left branch will be a perfect fit
 		found.reset();
 		alg.findNeighbor(new double[]{2, 0.8}, 1, found);
-		assertTrue(found.data[0].node == tree.root.left.right);
+		assertSame(found.data[0].node, tree.root.left.right);
 
 		// a point way outside the tree's bounds
 		found.reset();
 		alg.findNeighbor(new double[]{-10000, 0.5}, 1, found);
-		assertTrue(found.data[0].node == tree.root.left.left);
+		assertSame(found.data[0].node, tree.root.left.left);
 	}
 
 	/**
@@ -99,7 +100,7 @@ public abstract class StandardKdTreeSearchNTests {
 		// the first decision will be incorrect and it will need to back track
 		found.reset();
 		alg.findNeighbor(new double[]{2, 3}, 1, found);
-		assertTrue(found.get(0).node == tree.root);
+		assertSame(found.get(0).node, tree.root);
 
 	}
 
@@ -113,7 +114,7 @@ public abstract class StandardKdTreeSearchNTests {
 		KdTree tree = StandardKdTreeSearch1Tests.createTreeA();
 		setTree(alg,tree);
 
-		List<double[]> data = new ArrayList<double[]>();
+		List<double[]> data = new ArrayList<>();
 		flattenTree(tree.root,data);
 
 		for( int i = 0; i < 100; i++ ) {
@@ -163,11 +164,11 @@ public abstract class StandardKdTreeSearchNTests {
 		found.reset();
 		alg.findNeighbor(new double[]{11, 8}, 2, found);
 		assertEquals(1,found.size);
-		assertTrue(found.data[0].node == tree.root);
+		assertSame(found.data[0].node, tree.root);
 		found.reset();
 		alg.findNeighbor(new double[]{2, 5}, 2, found);
 		assertEquals(1,found.size);
-		assertTrue(found.data[0].node == tree.root);
+		assertSame(found.data[0].node, tree.root);
 	}
 
 	/**
@@ -188,7 +189,7 @@ public abstract class StandardKdTreeSearchNTests {
 		found.reset();
 		alg.findNeighbor(new double[]{1, 1.5}, 1, found);
 		assertEquals(1, found.size);
-		assertTrue(found.data[0].node == tree.root);
+		assertSame(found.data[0].node, tree.root);
 	}
 
 	/**
@@ -233,20 +234,11 @@ public abstract class StandardKdTreeSearchNTests {
 		for( int i = 0; i < 3; i++ ) {
 			double[] a = (double[])found.get(i).node.point;
 			for( int j = i+1; j < 3; j++ ) {
-				assertTrue(found.get(j).node.point != a);
+				assertNotSame(found.get(j).node.point, a);
 			}
 		}
 	}
 
-	private void checkContains( KdTree.Node node ) {
-		for( int i = 0; i < found.size; i++ ) {
-			if( found.data[i].node == node )
-				return;
-		}
-
-		fail("can't find");
-	}
-
 	private void checkContains( double[] d ) {
 		for( int i = 0; i < found.size; i++ ) {
 			boolean identical = true;
@@ -273,11 +265,11 @@ public abstract class StandardKdTreeSearchNTests {
 	}
 
 	private static List<double[]> findNeighbors( List<double[]> data , double[]target , double maxDistance , int maxN ) {
-		List<double[]> ret = new ArrayList<double[]>();
+		List<double[]> ret = new ArrayList<>();
 
-		List<double[]> found = new ArrayList<double[]>();
-		GrowQueue_F64 distances = new GrowQueue_F64();
-		GrowQueue_I32 indexes = new GrowQueue_I32();
+		List<double[]> found = new ArrayList<>();
+		DogArray_F64 distances = new DogArray_F64();
+		DogArray_I32 indexes = new DogArray_I32();
 
 
 		for( int i = 0; i < data.size(); i++ ) {
