@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2013, Peter Abeles. All Rights Reserved.
+ * Copyright (c) 2012-2020, Peter Abeles. All Rights Reserved.
  *
  * This file is part of DDogleg (http://ddogleg.org).
  *
@@ -23,4 +23,11 @@ package org.ddogleg.struct;
  */
 public class DummyData {
 	public int value;
+
+	public DummyData(int value) {
+		this.value = value;
+	}
+
+	public DummyData() {
+	}
 }
